Modules
=======

:mod:`emase` Package
--------------------

.. automodule:: emase.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`AlignmentMatrixFactory` Module
------------------------------------

.. automodule:: emase.AlignmentMatrixFactory
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Sparse3DMatrix` Module
----------------------------

.. automodule:: emase.Sparse3DMatrix
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`AlignmentPropertyMatrix` Module
-------------------------------------

.. automodule:: emase.AlignmentPropertyMatrix
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`EMfactory` Module
-----------------------

.. automodule:: emase.EMfactory
    :members:
    :undoc-members:
    :show-inheritance:

